@@ -7,8 +7,8 @@ import java.io.* ;
 
 public class InlineJavaPerlNatives extends InlineJavaPerlCaller {
 	static private boolean inited = false ;
-	static private HashMap registered_classes = new HashMap() ;
-	static private HashMap registered_methods = new HashMap() ;
+	static private Map registered_classes = Collections.synchronizedMap(new HashMap()) ;
+	static private Map registered_methods = Collections.synchronizedMap(new HashMap()) ;
 
 
 	protected InlineJavaPerlNatives() throws InlineJavaException {
